import json
from typing import Any, Iterable, List, Literal, Optional, Union

import httpx

from xima_ai._vendor.openai.types.responses.response_includable import (
    ResponseIncludable,
)
from xima_ai._vendor.openai.types.responses.response_input_item_param import (
    ResponseInputItemParam,
)
from xima_ai.api_resources.apis.api_resource import APIResource, AsyncAPIResource
from xima_ai.api_resources.client import AsyncPortkey, XimaAi
from xima_ai.api_resources.types.conversation_type import (
    Conversation,
    ConversationDeletedResource,
)
from xima_ai.api_resources.types.shared_types import Headers, Metadata, Query

from ..._vendor.openai._types import NOT_GIVEN, Body, NotGiven, Omit, omit


class Conversations(APIResource):
    def __init__(self, client: XimaAi) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client
        self.items = ConversationsItems(client)

    def create(
        self,
        *,
        items: Union[Optional[Iterable[ResponseInputItemParam]], Omit] = omit,
        metadata: Union[Optional[Metadata], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = self.openai_client.with_raw_response.conversations.create(
            items=items,
            metadata=metadata,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    def retrieve(
        self,
        conversation_id: str,
        *,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = self.openai_client.with_raw_response.conversations.retrieve(
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    def update(
        self,
        conversation_id: str,
        *,
        metadata: Metadata,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = self.openai_client.with_raw_response.conversations.update(
            conversation_id=conversation_id,
            metadata=metadata,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    def delete(
        self,
        conversation_id: str,
        *,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> ConversationDeletedResource:
        response = self.openai_client.with_raw_response.conversations.delete(
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = ConversationDeletedResource(**json.loads(response.text))
        data._headers = response.headers

        return data


class AsyncConversations(AsyncAPIResource):
    def __init__(self, client: AsyncPortkey) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client
        self.items = AsyncConversationsItems(client)

    async def create(
        self,
        *,
        items: Union[Optional[Iterable[ResponseInputItemParam]], Omit] = omit,
        metadata: Union[Optional[Metadata], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = await self.openai_client.with_raw_response.conversations.create(
            items=items,
            metadata=metadata,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    async def retrieve(
        self,
        conversation_id: str,
        *,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = await self.openai_client.with_raw_response.conversations.retrieve(
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    async def update(
        self,
        conversation_id: str,
        *,
        metadata: Metadata,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Conversation:
        response = await self.openai_client.with_raw_response.conversations.update(
            conversation_id=conversation_id,
            metadata=metadata,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = Conversation(**json.loads(response.text))
        data._headers = response.headers

        return data

    async def delete(
        self,
        conversation_id: str,
        *,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> ConversationDeletedResource:
        response = await self.openai_client.with_raw_response.conversations.delete(
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )
        data = ConversationDeletedResource(**json.loads(response.text))
        data._headers = response.headers

        return data


class ConversationsItems(APIResource):
    def __init__(self, client: XimaAi) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client

    def create(
        self,
        conversation_id: str,
        *,
        items: Iterable[ResponseInputItemParam],
        include: Union[List[ResponseIncludable], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = self.openai_client.conversations.items.create(
            conversation_id=conversation_id,
            items=items,
            include=include,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    def retrieve(
        self,
        item_id: str,
        *,
        conversation_id: str,
        include: Union[List[ResponseIncludable], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = self.openai_client.conversations.items.retrieve(
            item_id=item_id,
            conversation_id=conversation_id,
            include=include,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    def list(
        self,
        conversation_id: str,
        *,
        after: Union[str, Omit] = omit,
        include: Union[List[ResponseIncludable], Omit] = omit,
        limit: Union[int, Omit] = omit,
        order: Union[Omit, Literal["asc", "desc"]] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = self.openai_client.conversations.items.list(
            conversation_id=conversation_id,
            after=after,
            include=include,
            limit=limit,
            order=order,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    def delete(
        self,
        item_id: str,
        *,
        conversation_id: str,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = self.openai_client.conversations.items.delete(
            item_id=item_id,
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response


class AsyncConversationsItems(AsyncAPIResource):
    def __init__(self, client: AsyncPortkey) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client

    async def create(
        self,
        conversation_id: str,
        *,
        items: Iterable[ResponseInputItemParam],
        include: Union[List[ResponseIncludable], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = await self.openai_client.conversations.items.create(
            conversation_id=conversation_id,
            items=items,
            include=include,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    async def retrieve(
        self,
        item_id: str,
        *,
        conversation_id: str,
        include: Union[List[ResponseIncludable], Omit] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = await self.openai_client.conversations.items.retrieve(
            item_id=item_id,
            conversation_id=conversation_id,
            include=include,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    async def list(
        self,
        conversation_id: str,
        *,
        after: Union[str, Omit] = omit,
        include: Union[List[ResponseIncludable], Omit] = omit,
        limit: Union[int, Omit] = omit,
        order: Union[Omit, Literal["asc", "desc"]] = omit,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = await self.openai_client.conversations.items.list(
            conversation_id=conversation_id,
            after=after,
            include=include,
            limit=limit,
            order=order,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response

    async def delete(
        self,
        item_id: str,
        *,
        conversation_id: str,
        extra_headers: Optional[Headers] = None,
        extra_query: Optional[Query] = None,
        extra_body: Optional[Body] = None,
        timeout: Union[float, httpx.Timeout, NotGiven] = NOT_GIVEN,
    ) -> Any:
        response = await self.openai_client.conversations.items.delete(
            item_id=item_id,
            conversation_id=conversation_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
        )

        return response



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .realtime_response_create_params import RealtimeResponseCreateParams

__all__ = ["ResponseCreateEvent"]


class ResponseCreateEvent(BaseModel):
    type: Literal["response.create"]
    """The event type, must be `response.create`."""

    event_id: Optional[str] = None
    """Optional client-generated ID used to identify this event."""

    response: Optional[RealtimeResponseCreateParams] = None
    """Create a new Realtime response with these parameters"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["AudioTranscriptionParam"]


class AudioTranscriptionParam(TypedDict, total=False):
    language: str
    """The language of the input audio.

    Supplying the input language in
    [ISO-639-1](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) (e.g. `en`)
    format will improve accuracy and latency.
    """

    model: Literal["whisper-1", "gpt-4o-transcribe-latest", "gpt-4o-mini-transcribe", "gpt-4o-transcribe"]
    """The model to use for transcription.

    Current options are `whisper-1`, `gpt-4o-transcribe-latest`,
    `gpt-4o-mini-transcribe`, and `gpt-4o-transcribe`.
    """

    prompt: str
    """
    An optional text to guide the model's style or continue a previous audio
    segment. For `whisper-1`, the
    [prompt is a list of keywords](https://platform.openai.com/docs/guides/speech-to-text#prompting).
    For `gpt-4o-transcribe` models, the prompt is a free text string, for example
    "expect words related to technology".
    """



from .chat_complete import (
    ChatCompletion,
    AsyncChatCompletion,
    ChatCompletionsMessages,
    AsyncChatCompletionsMessages,
)
from .complete import Completion, AsyncCompletion
from .generation import Generations, AsyncGenerations, Prompts, AsyncPrompts
from .feedback import Feedback, AsyncFeedback
from .create_headers import createHeaders
from .post import Post, AsyncPost
from .getMethod import GetMethod, AsyncGetMethod
from .deleteMethod import DeleteMethod, AsyncDeleteMethod
from .putMethod import PutMethod, AsyncPutMethod
from .embeddings import Embeddings, AsyncEmbeddings
from .images import Images, AsyncImages
from .assistants import Assistants, AsyncAssistants
from .threads import (
    Threads,
    Messages,
    Runs,
    Steps,
    AsyncThreads,
    AsyncMessages,
    AsyncRuns,
    AsyncSteps,
)
from .main_files import MainFiles, AsyncMainFiles
from .models import Models, AsyncModels
from .moderations import Moderations, AsyncModerations
from .audio import (
    Audio,
    Transcriptions,
    Translations,
    Speech,
    AsyncAudio,
    AsyncTranscriptions,
    AsyncTranslations,
    AsyncSpeech,
)
from .batches import Batches, AsyncBatches
from .fine_tuning import (
    FineTuning,
    Jobs,
    Checkpoints,
    Alpha,
    Graders,
    AsyncFineTuning,
    AsyncJobs,
    AsyncCheckpoints,
    FineTuningCheckpoints,
    Permissions,
    AsyncFineTuningCheckpoints,
    AsyncPermissions,
    AsyncAlpha,
    AsyncGraders,
)
from .vector_stores import (
    VectorStores,
    VectorFiles,
    VectorFileBatches,
    AsyncVectorStores,
    AsyncVectorFiles,
    AsyncVectorFileBatches,
)
from .admin import (
    Admin,
    Users,
    Invites,
    Workspaces,
    WorkspacesUsers,
    AsyncAdmin,
    AsyncUsers,
    AsyncInvites,
    AsyncWorkspaces,
    AsyncWorkspacesUsers,
)

from .beta_chat import (
    BetaChat,
    BetaCompletions,
    AsyncBetaChat,
    AsyncBetaCompletions,
)

from .beta_realtime import (
    BetaRealtime,
    AsyncBetaRealtime,
    BetaSessions,
    AsyncBetaSessions,
    BetaTranscriptionSessions,
    AsyncBetaTranscriptionSessions,
)

from .responses import (
    Responses,
    InputItems,
    AsyncResponses,
    AsyncInputItems,
)

from .uploads import (
    Uploads,
    Parts,
    AsyncUploads,
    AsyncParts,
)

from .evals import (
    Evals,
    AsyncEvals,
    EvalsRuns,
    AsyncEvalsRuns,
    OutputItems,
    AsyncOutputItems,
)

from .containers import (
    Containers,
    AsyncContainers,
    ContainersFiles,
    AsyncContainersFiles,
    Content,
    AsyncContent,
)

from .webhooks import Webhooks, AsyncWebhooks

from .configs import Configs, AsyncConfigs

from .api_keys import ApiKeys, AsyncApiKeys
from .virtual_keys import VirtualKeys, AsyncVirtualKeys
from .logs import Logs, AsyncLogs

from .labels import Labels, AsyncLabels

from .collections import Collections, AsyncCollections

from .integrations import (
    Integrations,
    AsyncIntegrations,
    IntegrationsWorkspaces,
    AsyncIntegrationsWorkspaces,
    IntegrationsModels,
    AsyncIntegrationsModels,
)

from .providers import (
    Providers,
    AsyncProviders,
)

from .guardrails import (
    Guardrails,
    AsyncGuardrails,
)

from .main_realtime import (
    MainRealtime,
    AsyncMainRealtime,
    ClientSecrets,
    AsyncClientSecrets,
    Calls,
    AsyncCalls,
)

from .conversations import (
    Conversations,
    AsyncConversations,
    ConversationsItems,
    AsyncConversationsItems,
)

from .videos import Videos, AsyncVideos

from .chatkit import (
    ChatKit,
    AsyncChatKit,
    ChatKitSessions,
    AsyncChatKitSessions,
    ChatKitThreads,
    AsyncChatKitThreads,
)

__all__ = [
    "Completion",
    "AsyncCompletion",
    "ChatCompletion",
    "AsyncChatCompletion",
    "ChatCompletionsMessages",
    "AsyncChatCompletionsMessages",
    "Generations",
    "AsyncGenerations",
    "Feedback",
    "AsyncFeedback",
    "Prompts",
    "AsyncPrompts",
    "createHeaders",
    "Post",
    "AsyncPost",
    "GetMethod",
    "AsyncGetMethod",
    "DeleteMethod",
    "AsyncDeleteMethod",
    "PutMethod",
    "AsyncPutMethod",
    "Embeddings",
    "AsyncEmbeddings",
    "Images",
    "AsyncImages",
    "Assistants",
    "AsyncAssistants",
    "MainFiles",
    "AsyncMainFiles",
    "Models",
    "AsyncModels",
    "Threads",
    "AsyncThreads",
    "Messages",
    "AsyncMessages",
    "Runs",
    "AsyncRuns",
    "Steps",
    "AsyncSteps",
    "Moderations",
    "AsyncModerations",
    "Audio",
    "Transcriptions",
    "Translations",
    "Speech",
    "AsyncAudio",
    "AsyncTranscriptions",
    "AsyncTranslations",
    "AsyncSpeech",
    "Batches",
    "AsyncBatches",
    "FineTuning",
    "Jobs",
    "Checkpoints",
    "AsyncFineTuning",
    "AsyncJobs",
    "AsyncCheckpoints",
    "VectorStores",
    "VectorFiles",
    "VectorFileBatches",
    "AsyncVectorStores",
    "AsyncVectorFiles",
    "AsyncVectorFileBatches",
    "Admin",
    "Users",
    "Invites",
    "Workspaces",
    "WorkspacesUsers",
    "AsyncAdmin",
    "AsyncUsers",
    "AsyncInvites",
    "AsyncWorkspaces",
    "AsyncWorkspacesUsers",
    "BetaChat",
    "BetaCompletions",
    "AsyncBetaChat",
    "AsyncBetaCompletions",
    "Uploads",
    "Parts",
    "AsyncUploads",
    "AsyncParts",
    "Configs",
    "AsyncConfigs",
    "ApiKeys",
    "AsyncApiKeys",
    "VirtualKeys",
    "AsyncVirtualKeys",
    "Logs",
    "AsyncLogs",
    "BetaRealtime",
    "AsyncBetaRealtime",
    "BetaSessions",
    "AsyncBetaSessions",
    "BetaTranscriptionSessions",
    "AsyncBetaTranscriptionSessions",
    "Responses",
    "InputItems",
    "AsyncResponses",
    "AsyncInputItems",
    "Labels",
    "AsyncLabels",
    "Collections",
    "AsyncCollections",
    "FineTuningCheckpoints",
    "AsyncFineTuningCheckpoints",
    "Permissions",
    "AsyncPermissions",
    "Evals",
    "AsyncEvals",
    "EvalsRuns",
    "AsyncEvalsRuns",
    "OutputItems",
    "AsyncOutputItems",
    "Alpha",
    "AsyncAlpha",
    "Graders",
    "AsyncGraders",
    "Containers",
    "AsyncContainers",
    "ContainersFiles",
    "AsyncContainersFiles",
    "Content",
    "AsyncContent",
    "Integrations",
    "AsyncIntegrations",
    "IntegrationsWorkspaces",
    "AsyncIntegrationsWorkspaces",
    "IntegrationsModels",
    "AsyncIntegrationsModels",
    "Providers",
    "AsyncProviders",
    "Guardrails",
    "AsyncGuardrails",
    "Webhooks",
    "AsyncWebhooks",
    "MainRealtime",
    "AsyncMainRealtime",
    "ClientSecrets",
    "AsyncClientSecrets",
    "Conversations",
    "AsyncConversations",
    "ConversationsItems",
    "AsyncConversationsItems",
    "Videos",
    "AsyncVideos",
    "ChatKit",
    "AsyncChatKit",
    "ChatKitSessions",
    "AsyncChatKitSessions",
    "ChatKitThreads",
    "AsyncChatKitThreads",
    "Calls",
    "AsyncCalls",
]



import json
from typing import Any, Iterable, List, Union

from xima_ai.api_resources.apis.api_resource import APIResource, AsyncAPIResource
from xima_ai.api_resources.client import AsyncPortkey, XimaAi
from xima_ai.api_resources.types.moderations_type import ModerationCreateResponse

from ..._vendor.openai._types import Omit, omit


class Moderations(APIResource):
    def __init__(self, client: XimaAi) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client

    def create(
        self,
        *,
        input: Union[str, List[str], Iterable[Any]],
        model: Union[str, Omit] = omit,
        **kwargs,
    ) -> ModerationCreateResponse:
        response = self.openai_client.with_raw_response.moderations.create(
            input=input, model=model, extra_body=kwargs
        )
        data = ModerationCreateResponse(**json.loads(response.text))
        data._headers = response.headers

        return data


class AsyncModerations(AsyncAPIResource):
    def __init__(self, client: AsyncPortkey) -> None:
        super().__init__(client)
        self.openai_client = client.openai_client

    async def create(
        self,
        *,
        input: Union[str, List[str], Iterable[Any]],
        model: Union[str, Omit] = omit,
        **kwargs,
    ) -> ModerationCreateResponse:
        response = await self.openai_client.with_raw_response.moderations.create(
            input=input, model=model, extra_body=kwargs
        )
        data = ModerationCreateResponse(**json.loads(response.text))
        data._headers = response.headers

        return data
